try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="87f5ab9a-a7a7-4033-81a4-31451724d7e6",e._sentryDebugIdIdentifier="sentry-dbid-87f5ab9a-a7a7-4033-81a4-31451724d7e6")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.04.28-e984b46"}}catch(e){}}(),exports.id=5357,exports.ids=[5357],exports.modules={"../ink/build/devtools.js":(e,n,d)=>{var l=d("../../node_modules/.pnpm/ws@8.18.2/node_modules/ws/wrapper.mjs");const t=global;t.WebSocket||=l.Ay,t.window||=global,t.self||=global,t.window.__REACT_DEVTOOLS_COMPONENT_FILTERS__=[{type:1,value:7,isEnabled:!0},{type:2,value:"InternalApp",isEnabled:!0,isValid:!0},{type:2,value:"InternalAppContext",isEnabled:!0,isValid:!0},{type:2,value:"InternalStdoutContext",isEnabled:!0,isValid:!0},{type:2,value:"InternalStderrContext",isEnabled:!0,isValid:!0},{type:2,value:"InternalStdinContext",isEnabled:!0,isValid:!0},{type:2,value:"InternalFocusContext",isEnabled:!0,isValid:!0}];var o=d("../../node_modules/.pnpm/react-devtools-core@7.0.1/node_modules/react-devtools-core/dist/backend.js");o.initialize(),o.connectToDevTools()}};