try{!function(){var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="72e608bc-87e9-4674-805e-c51928ca3079",e._sentryDebugIdIdentifier="sentry-dbid-72e608bc-87e9-4674-805e-c51928ca3079")}()}catch(e){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.04.28-e984b46"}}catch(e){}}(),exports.id=7469,exports.ids=[7469],exports.modules={"./src/commands/install-shell-integration.ts":(e,n,t)=>{t.r(n),t.d(n,{handleInstallShellIntegration:()=>c});var l=t("node:fs"),i=t("node:os"),o=t("node:path"),s=t.n(o),r=t("./src/console-io.ts");const a='eval "$(~/.local/bin/agent shell-integration zsh)"',d='eval "$(~/.local/bin/cursor-agent shell-integration zsh)"';function c(){const e=s().join((0,i.homedir)(),".zshrc");try{let n="";try{n=(0,l.readFileSync)(e,"utf8")}catch(e){if("ENOENT"!==e.code)throw e;n=""}if(n.includes(a)||n.includes(d))return void(0,r.p2)("Shell integration is already installed in ~/.zshrc");const t=`${a}\n${n}`;(0,l.writeFileSync)(e,t,"utf8"),(0,r.p2)("Shell integration installed successfully!"),(0,r.p2)("Please restart your terminal or run 'source ~/.zshrc' to activate.")}catch(e){(0,r.p2)(`Failed to install shell integration: ${String(e)}`),process.exit(1)}}}};